==> ojalgo_51.4.0+ds.orig.tar.xz: ojAlgo-51.4.0/src/main/java/org/ojalgo/random/Erlang.java <==
/*
 * Copyright 1997-2022 Optimatika
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.ojalgo.random;

import static org.ojalgo.function.constant.PrimitiveMath.*;

import org.ojalgo.function.constant.PrimitiveMath;

/**
 * Distribution of the sum of aCount random variables with an exponential distribution with parameter aLambda.
 *
 * @author apete
 */
public class Erlang extends RandomNumber {

    private final int myCount;
    private final double myRate;

    public Erlang() {
        this((int) ONE, ONE);
    }

    public Erlang(final int aCount, final double aRate) {

        super();

        myCount = aCount;
        myRate = aRate;
    }

    public double getExpected() {
        return myCount / myRate;
    }

    @Override
    public double getVariance() {
        return myCount / (myRate * myRate);
    }

    @Override
    protected double generate() {

        double tmpVal = ZERO;

        for (int i = 0; i < myCount; i++) {
            tmpVal -= PrimitiveMath.LOG.invoke(RandomNumber.random().nextDouble());
        }

        return tmpVal / myRate;
    }

}

==> ojalgo_53.3.0+ds.orig.tar.xz: ojAlgo-53.3.0/src/main/java/org/ojalgo/random/Erlang.java <==
/*
 * Copyright 1997-2024 Optimatika
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.ojalgo.random;

import static org.ojalgo.function.constant.PrimitiveMath.*;

import org.ojalgo.function.constant.PrimitiveMath;

/**
 * Distribution of the sum of aCount random variables with an exponential distribution with parameter aLambda.
 *
 * @author apete
 */
public class Erlang extends RandomNumber {

    private final int myCount;
    private final double myRate;

    public Erlang() {
        this((int) ONE, ONE);
    }

    public Erlang(final int aCount, final double aRate) {

        super();

        myCount = aCount;
        myRate = aRate;
    }

    public double getExpected() {
        return myCount / myRate;
    }

    @Override
    public double getVariance() {
        return myCount / (myRate * myRate);
    }

    @Override
    protected double generate() {

        double tmpVal = ZERO;

        for (int i = 0; i < myCount; i++) {
            tmpVal -= PrimitiveMath.LOG.invoke(this.random().nextDouble());
        }

        return tmpVal / myRate;
    }

}
